Testing Config Tracker
======================

The :class:`Tracker.Config` lists configuration values 
from a cgatreport`ConfigParser` file.

.. report:: Tracker.Config
   :tracks: conf.ini
   :render: table
   
   Table with pipeline parameters.
